==> ecs_1.4.0.orig.tar.gz: ecs-1.4.0/inc/util/ecs_chaine_glob.h <==
#ifndef _ECS_CHAINE_GLOB_H_
#define _ECS_CHAINE_GLOB_H_

/*============================================================================
 *  Noms et chanes de caractres diverses
 *============================================================================*/

/*
  This file is part of the Code_Saturne Preprocessor, element of the
  Code_Saturne CFD tool.

  Copyright (C) 1999-2007 EDF S.A., France

  contact: saturne-support@edf.fr

  The Code_Saturne Preprocessor is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2 of
  the License, or (at your option) any later version.

  The Code_Saturne Preprocessor is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied warranty
  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with the Code_Saturne Preprocessor; if not, write to the
  Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor,
  Boston, MA  02110-1301  USA
*/


/*============================================================================
 *                       Dfinition de macros
 *============================================================================*/

/* Noms des maillages */
/*--------------------*/

/* Maillages "standards" */

#define ECS_MAILLAGE_NOM_FAC_ISOLEE                      N_("Isolated Faces")
#define ECS_MAILLAGE_NOM_BORD                                  N_("Boundary")
#define ECS_MAILLAGE_NOM_FAC_ERR_CONNECT       N_("Connectivity Error Faces")

#define ECS_MAILLAGE_NOM_PRINCIPAL                         N_("Fluid Domain")

/* Maillages pour debug orientation */

#define ECS_MAILLAGE_NOM_ORIENT_ERR                  N_("Orientation Error")
#define ECS_MAILLAGE_NOM_ORIENT_CORRECT          N_("Orientation Corrected")


/* Noms des entites de maillage */
/*------------------------------*/

#define ECS_NOM_CEL_ERR_RC                               N_("Joining_Error")
#define ECS_NOM_CEL_ERR_PERIO                        N_("Periodicity_Error")

#define ECS_NOM_FACES_ERR_RC_AUTO                 N_("Faces: joining error")
#define ECS_NOM_FACES_NEW_RC_AUTO                        N_("Faces: joined")
#define ECS_NOM_FACES_MOD_RC_AUTO                N_("Faces: mod by joining")
#define ECS_NOM_FACES_ERR_RC                      N_("Faces: joining error")
#define ECS_NOM_FACES_NEW_RC                             N_("Faces: joined")
#define ECS_NOM_FACES_MOD_RC                     N_("Faces: mod by joining")
#define ECS_NOM_FACES_ERR_PERIO               N_("Faces: periodicity error")
#define ECS_NOM_FACES_PERIO                            N_("Faces: periodic")
#define ECS_NOM_FACES_MOD_PERIO              N_("Faces: mod by periodicity")
#define ECS_NOM_FACES_SELECT                 N_("Internal Faces: selection")


#endif /* _ECS_CHAINE_GLOB_H_ */

==> ecs_2.0.0.rc1.orig.tar.gz: ecs-2.0.0-rc1/inc/util/ecs_chaine_glob.h <==
#ifndef _ECS_CHAINE_GLOB_H_
#define _ECS_CHAINE_GLOB_H_

/*============================================================================
 *  Noms et chaînes de caractères diverses
 *============================================================================*/

/*
  This file is part of the Code_Saturne Preprocessor, element of the
  Code_Saturne CFD tool.

  Copyright (C) 1999-2007 EDF S.A., France

  contact: saturne-support@edf.fr

  The Code_Saturne Preprocessor is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2 of
  the License, or (at your option) any later version.

  The Code_Saturne Preprocessor is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied warranty
  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with the Code_Saturne Preprocessor; if not, write to the
  Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor,
  Boston, MA  02110-1301  USA
*/


/*============================================================================
 *                       Définition de macros
 *============================================================================*/

/* Noms des maillages */
/*--------------------*/

/* Maillages "standards" */

#define ECS_MAILLAGE_NOM_FAC_ISOLEE                      N_("Isolated Faces")
#define ECS_MAILLAGE_NOM_BORD                                  N_("Boundary")
#define ECS_MAILLAGE_NOM_FAC_ERR_CONNECT       N_("Connectivity Error Faces")

#define ECS_MAILLAGE_NOM_PRINCIPAL                         N_("Fluid Domain")

/* Maillages pour debug orientation */

#define ECS_MAILLAGE_NOM_ORIENT_ERR                  N_("Orientation Error")
#define ECS_MAILLAGE_NOM_ORIENT_CORRECT          N_("Orientation Corrected")


/* Noms des entites de maillage */
/*------------------------------*/

#define ECS_NOM_CEL_ERR_RC                               N_("Joining_Error")
#define ECS_NOM_CEL_ERR_PERIO                        N_("Periodicity_Error")

#define ECS_NOM_FACES_ERR_RC_AUTO                 N_("Faces: joining error")
#define ECS_NOM_FACES_NEW_RC_AUTO                        N_("Faces: joined")
#define ECS_NOM_FACES_MOD_RC_AUTO                N_("Faces: mod by joining")
#define ECS_NOM_FACES_ERR_RC                      N_("Faces: joining error")
#define ECS_NOM_FACES_NEW_RC                             N_("Faces: joined")
#define ECS_NOM_FACES_MOD_RC                     N_("Faces: mod by joining")
#define ECS_NOM_FACES_ERR_PERIO               N_("Faces: periodicity error")
#define ECS_NOM_FACES_PERIO                            N_("Faces: periodic")
#define ECS_NOM_FACES_MOD_PERIO              N_("Faces: mod by periodicity")
#define ECS_NOM_FACES_SELECT                 N_("Internal Faces: selection")


#endif /* _ECS_CHAINE_GLOB_H_ */
